@@ -1,14 +1,22 @@
 """Module for interacting with the Castor EDC API."""
+
+import asyncio
 import csv
+import json
+import sys
 from datetime import datetime
 from itertools import chain
-import asyncio
-from typing import Optional, List, Union
+from typing import List, Optional, Union
 
 import httpx
 from httpx import HTTPStatusError
 from tqdm import tqdm
 
+if sys.version_info >= (3, 8):
+    from importlib import metadata as pkg_metadata
+else:
+    import importlib_metadata as pkg_metadata
+
 
 class CastorException(Exception):
     """Exception class for interacting with Castor database"""
@@ -23,13 +31,8 @@ class CastorClient:
     # Necessary number of public methods to interact with API
 
     # INITIALIZATION
-    headers = {
-        "accept": "*/*",  # "application/hal+json; text/csv",
-        "Content-Type": "application/json; charset=utf-8",
-    }
-
     # Limits for server load
-    max_connections = 30
+    max_connections = 15
     timeout = httpx.Timeout(10.0, read=60)
     limits = httpx.Limits(max_connections=max_connections)
 
@@ -41,18 +44,29 @@ class CastorClient:
         self.base_url = f"https://{url}/api"
         self.auth_url = f"https://{url}/oauth/token"
 
-        # Grab authentication token for given client
-        token = self.request_auth_token(client_id, client_secret)
-        self.headers["authorization"] = "Bearer " + token
-
-        # Instantiate global study variables
-        self.study_url = None
+        try:
+            self.package_version = pkg_metadata.version("castoredc_api")
+        except pkg_metadata.PackageNotFoundError:
+            self.package_version = "dev"
 
         # Instantiate client
         self.client = httpx.Client(
-            headers=self.headers, limits=self.limits, timeout=self.timeout
+            headers={
+                "accept": "*/*",  # "application/hal+json; text/csv",
+                "Content-Type": "application/json; charset=utf-8",
+                "User-Agent": f"python-castoredc_api/{self.package_version}",
+            },
+            limits=self.limits,
+            timeout=self.timeout,
         )
 
+        # Grab authentication token for given client
+        token = self.request_auth_token(client_id, client_secret)
+        self.client.headers["authorization"] = "Bearer " + token
+
+        # Instantiate global study variables
+        self.study_url = None
+
     def link_study(self, study_id):
         """Link a study based on the study_id."""
         self.study_url = self.base_url + "/study/" + study_id
@@ -217,7 +231,9 @@ class CastorClient:
         post_data = {"common": common, "data": body}
         return self.sync_post(url, post_data)
 
-    def update_survey_instance_data_record(self, record_id, survey_instance_id, body):
+    def update_survey_instance_data_record(
+        self, record_id, survey_instance_id, body, change_reason
+    ):
         """Creates/updates a survey instance.
         Returns None if record not found.
         Post Data Models:
@@ -231,11 +247,11 @@ class CastorClient:
             self.study_url
             + f"/record/{record_id}/data-point-collection/survey-instance/{survey_instance_id}"
         )
-        post_data = {"data": body}
+        post_data = {"data": body, "common": {"change_reason": change_reason}}
         return self.sync_post(url, post_data)
 
     def update_survey_package_instance_data_record(
-        self, record_id, survey_package_instance_id, body, filled_on=None
+        self, record_id, survey_package_instance_id, body, change_reason, filled_on=None
     ):
         """Creates/updates a survey package instance.
         Returns None if record not found.
@@ -252,7 +268,7 @@ class CastorClient:
             self.study_url + f"/record/{record_id}/data-point-collection/"
             f"survey-package-instance/{survey_package_instance_id}"
         )
-        post_data = {"data": body}
+        post_data = {"data": body, "common": {"change_reason": change_reason}}
         # Validate and format datetime
         if filled_on:
             if isinstance(filled_on, str):
@@ -272,6 +288,7 @@ class CastorClient:
                 "exclude_empty_surveys": exclude_empty_surveys,
                 "exclude_empty_reports": exclude_empty_reports,
             },
+            timeout=httpx.Timeout(10.0, read=300),
         )["content"]
 
     def export_study_structure(self):
@@ -290,7 +307,7 @@ class CastorClient:
         return self.retrieve_all_data_by_endpoint(
             endpoint="/field",
             data_name="fields",
-            params={"include": "metadata|validations|optiongroup"},
+            params={"include": "metadata,validations,optiongroup"},
         )
 
     def single_field(self, field_id):
@@ -299,7 +316,7 @@ class CastorClient:
         return self.retrieve_data_by_id(
             endpoint="/field",
             data_id=field_id,
-            params={"include": "metadata|validations|optiongroup"},
+            params={"include": "metadata,validations,optiongroup"},
         )
 
     # FIELD DEPENDENCY
@@ -697,10 +714,24 @@ class CastorClient:
         endpoint = f"/study/{study_id}/user/{user_id}"
         return self.retrieve_general_data(endpoint)
 
-    def invite_user_study(self, study_id, institute_id, email, message):
+    def invite_user_study(
+        self,
+        study_id,
+        institute_id,
+        email,
+        message,
+        manage_permissions=None,
+        institute_permissions=None,
+    ):
         """Invites user with email to the study linked to institute_id."""
         url = self.base_url + f"/study/{study_id}/user"
-        body = {"institute_id": institute_id, "email": email, "message": message}
+        body = {
+            "institute_id": institute_id,
+            "email": email,
+            "message": message,
+            "manage_permission": manage_permissions,
+            "institute_permissions": institute_permissions,
+        }
         return self.sync_post(url, body)
 
     # STUDY-DATA-ENTRY
@@ -963,7 +994,7 @@ class CastorClient:
             "client_secret": client_secret,
             "grant_type": "client_credentials",
         }
-        response = httpx.post(url=self.auth_url, data=auth_data)
+        response = self.client.post(url=self.auth_url, content=json.dumps(auth_data))
         response.raise_for_status()
         content = response.json()
         return content["access_token"]
@@ -1071,9 +1102,12 @@ class CastorClient:
         return response["total_items"]
 
     # Synchronous API Interaction
-    def sync_get(self, url: str, params: dict) -> dict:
+    def sync_get(self, url: str, params: dict, timeout=None) -> dict:
         """Synchronous querying of Castor API with a single get requests."""
-        response = self.client.get(url=url, params=params)
+        if timeout:
+            response = self.client.get(url=url, params=params, timeout=timeout)
+        else:
+            response = self.client.get(url=url, params=params)
         return self.handle_response(response)
 
     def sync_post(self, url, body):
@@ -1141,3 +1175,8 @@ class CastorClient:
         else:
             raise CastorException(f"{content_type} not supported")
         return data
+
+    @property
+    def headers(self):
+        """Return the headers that will be sent with each request"""
+        return self.client.headers
