@@ -330,6 +330,7 @@ study_model = {
         str,
     ],
     "expected_centers": [int, type(None)],
+    "trial_registry_id": [str, type(None)],
     "duration": [int, type(None)],
     "expected_records": [int, type(None)],
     "slug": [
@@ -510,6 +511,7 @@ package_model = {
         str,
     ],
     "allow_open_survey_link": [bool],
+    "field_pagination": [str],
     "survey_package_id": [
         str,
     ],
@@ -553,7 +555,11 @@ package_model = {
         str,
     ],
     "is_mobile": [bool],
+    "is_training": [bool],
     "expire_after_hours": [int, type(None)],
+    "is_repeatable": [bool],
+    "is_resumable": [bool],
+    "as_needed": [bool],
     "_embedded": [
         dict,
     ],
@@ -597,6 +603,7 @@ survey_package_instance_model = {
         str,
     ],
     "sent_on": [dict, type(None)],
+    "received_on": [dict, type(None)],
     "first_opened_on": [dict, type(None)],
     "finished_on": [dict, type(None)],
     "available_from": [dict],
@@ -723,6 +730,15 @@ survey_step_model = {
     "_links": [
         dict,
     ],
+    "label_bold_if_required": [
+        bool,
+    ],
+    "form_numbering": [
+        str,
+    ],
+    "field_alignment": [
+        str,
+    ],
 }
 
 field_dep_model = {
@@ -803,6 +819,9 @@ field_model = {
     ],
     "field_slider_step": [
         str,
+        type(None),
+    ],
+    "field_slider_step_value": [
         int,
         type(None),
     ],
@@ -890,6 +909,9 @@ institute_model = {
     "id": [
         str,
     ],
+    "date_format": [
+        str,
+    ],
     "institute_id": [
         str,
     ],
@@ -1024,6 +1046,10 @@ record_model = {
     "record_id": [
         str,
     ],
+    "record_status": [
+        str,
+        type(None),
+    ],
     "_embedded": [
         dict,
     ],
@@ -1091,6 +1117,9 @@ steps_model = {
     "signed": [
         bool,
     ],
+    "progress": [
+        int,
+    ],
 }
 
 statistics_model = {
