@@ -20,7 +20,7 @@ class TestCountry:
     model_keys = country_model.keys()
     single_country_model_keys = single_country_model.keys()
 
-    @pytest.fixture(scope="class")
+    @pytest.fixture(scope="function")
     def all_countries(self, client):
         """Returns a list of dicts containing all countries in the Castor database."""
         all_countries = client.all_countries()
@@ -86,22 +86,22 @@ class TestCountry:
         """Tests if retrieving a non-existent (edge case: upper range) country ID raises an error."""
         with pytest.raises(HTTPStatusError) as e:
             client.single_country(252)
-        assert "404 Client Error: Not Found for url" in str(e.value)
+        assert e.value.response.status_code == 404
 
     def test_single_country_failure_negative(self, client):
         """Tests if retrieving a non-existent (edge case: negative) country ID raises an error."""
         with pytest.raises(HTTPStatusError) as e:
             client.single_country(-1)
-        assert "404 Client Error: Not Found for url" in str(e.value)
+        assert e.value.response.status_code == 404
 
     def test_single_country_failure_zero(self, client):
         """Tests if retrieving a non-existent (edge case: zero) country ID raises an error."""
         with pytest.raises(HTTPStatusError) as e:
             client.single_country(0)
-        assert "404 Client Error: Not Found for url" in str(e.value)
+        assert e.value.response.status_code == 404
 
     def test_single_country_failure_one(self, client):
         """Tests if retrieving a non-existent (edge case: lower range) country ID raises an error."""
         with pytest.raises(HTTPStatusError) as e:
             client.single_country(1)
-        assert "404 Client Error: Not Found for url" in str(e.value)
+        assert e.value.response.status_code == 404
