@@ -42,7 +42,7 @@ class TestReportStep:
         },
     }
 
-    @pytest.fixture(scope="class")
+    @pytest.fixture(scope="function")
     def reports_with_steps(self, client):
         """Returns all the reports in the study with their corresponding steps."""
         reports_with_steps = {}
@@ -81,4 +81,4 @@ class TestReportStep:
                 "89FF2394-0D41-4D4C-89FE-AA9AB287B31E",
                 "111BA2F0-BC6B-47ED-9159-802BF760FAKE",
             )
-        assert "404 Client Error: Not Found for url" in str(e.value)
+        assert e.value.response.status_code == 404
