@@ -23,11 +23,12 @@ class TestStudyDataEntry:
         "field_variable_name": "ic_versions",
         "field_id": "28D1A17B-51C3-4BDC-A604-7B2F6D5D5924",
         "value": "1",
-        "updated_on": "2019-11-04 16:47:38",
+        "updated_on": "2019-11-04 15:47:38",
         "_embedded": {
             "record": {
                 "id": "000004",
                 "record_id": "000004",
+                "record_status": None,
                 "ccr_patient_id": "",
                 "last_opened_step": "FFF23B2C-AEE6-4304-9CC4-9C7C431D5387",
                 "locked": False,
@@ -43,7 +44,7 @@ class TestStudyDataEntry:
                 },
                 "updated_by": "B23ABCC4-3A53-FB32-7B78-3960CC907F25",
                 "updated_on": {
-                    "date": "2020-08-14 15:20:27.000000",
+                    "date": "2020-08-14 13:20:27.000000",
                     "timezone_type": 3,
                     "timezone": "Europe/Amsterdam",
                 },
@@ -57,6 +58,7 @@ class TestStudyDataEntry:
                         "institute_id": "1CFF5802-0B07-471F-B97E-B5166332F2C5",
                         "name": "Test Institute",
                         "abbreviation": "TES",
+                        "date_format": "d-m-Y",
                         "code": "TES",
                         "order": 0,
                         "deleted": False,
@@ -93,6 +95,7 @@ class TestStudyDataEntry:
                 "field_max_label": "",
                 "field_summary_template": "",
                 "field_slider_step": None,
+                "field_slider_step_value": None,
                 "report_id": "",
                 "field_length": None,
                 "additional_config": "",
@@ -131,7 +134,7 @@ class TestStudyDataEntry:
         """Test failing to return all study_data_points for a record"""
         with pytest.raises(HTTPStatusError) as e:
             client.all_study_fields_record("00FAKE")
-        assert "404 Client Error: Not Found for url" in str(e.value)
+        assert e.value.response.status_code == 404
 
     def test_single_study_data_point_record_success(self, client):
         """Tests returning a single study data point for a record"""
@@ -146,40 +149,40 @@ class TestStudyDataEntry:
             client.single_study_field_record(
                 "000004", "28D1A17B-51C3-4BDC-A604-7B2F6D5DFAKE"
             )
-        assert "500 Server Error: Internal Server Error for url:" in str(e.value)
+        assert e.value.response.status_code == 500
 
-    def test_update_single_study_field_record_success(self, client):
+    def test_update_single_study_field_record_success(self, write_client):
         """Tests changing a single study field."""
-        record = "000010"
-        field = "7E7868E1-946B-41EF-A96D-E3248251C6F1"
-        post_value = allowed_value(client, field)
+        record = "110001"
+        field = "4E6E5ECF-B195-416A-9813-4714141C1B93"
+        post_value = allowed_value(write_client, field)
 
         # Update the field
         change_reason = "Testing API"
-        client.update_single_study_field_record(
+        write_client.update_single_study_field_record(
             record, field, change_reason, post_value
         )
 
         # Check if changing worked
-        new_value = client.single_study_field_record(record, field)
+        new_value = write_client.single_study_field_record(record, field)
         assert new_value["value"] == str(post_value)
 
-    def test_update_single_study_field_record_fail(self, client):
+    def test_update_single_study_field_record_fail(self, write_client):
         """Tests failing to change a single study field."""
-        record = "000010"
-        field = "7E7868E1-946B-41EF-A96D-E3248251C6F1"
-        post_value = allowed_value(client, field)
-        old_value = client.single_study_field_record(record, field)
+        record = "110001"
+        field = "4E6E5ECF-B195-416A-9813-4714141C1B93"
+        post_value = allowed_value(write_client, field)
+        old_value = write_client.single_study_field_record(record, field)
 
         # Update the field
         change_reason = "Testing API"
 
         with pytest.raises(HTTPStatusError) as e:
-            client.update_single_study_field_record(
+            write_client.update_single_study_field_record(
                 record, "FAKE" + field + "FAKE", change_reason, post_value
             )
 
-        assert "500 Server Error: Internal Server Error for url:" in str(e.value)
+        assert e.value.response.status_code == 500
 
-        new_value = client.single_study_field_record(record, field)
+        new_value = write_client.single_study_field_record(record, field)
         assert new_value["value"] == old_value["value"]
