@@ -24,7 +24,7 @@ def create_survey_package_instance_body(record_id, fake):
     if fake:
         random_package = "FAKE"
     else:
-        random_package = "71C01598-4682-4A4C-90E6-69C0BD38EA47"
+        random_package = "4AAEDF4B-0137-46BD-BC4C-CC3E4BBF1588"
 
     return {
         "survey_package_id": random_package,
@@ -76,6 +76,11 @@ class TestSurveyEndpoints:
         "default_invitation_subject": "Please fill in this survey for Example Study",
         "sender_email": "no-reply@castoredc.com",
         "is_mobile": False,
+        "is_training": False,
+        "is_repeatable": False,
+        "is_resumable": False,
+        "field_pagination": "none",
+        "as_needed": False,
         "expire_after_hours": None,
         "_embedded": {
             "surveys": [
@@ -112,6 +117,7 @@ class TestSurveyEndpoints:
         "survey_package_id": "71C01598-4682-4A4C-90E6-69C0BD38EA47",
         "survey_url_string": "DUQKNQNN",
         "progress": 100,
+        "received_on": None,
         "invitation_subject": "Please fill in this survey for Example Study",
         "invitation_content": 'Dear participant,\n\nYou are participating in the study "Example Study" and we would like to ask you to fill in a survey.\n\nPlease click the link below to complete our survey.\n\n{url}\n\n{logo}',
         "created_on": {
@@ -143,6 +149,7 @@ class TestSurveyEndpoints:
             "record": {
                 "id": "000001",
                 "record_id": "000001",
+                "record_status": None,
                 "ccr_patient_id": "",
                 "last_opened_step": "1F1A5F3B-FD1A-45A6-9E0F-327F2EC68983",
                 "progress": 28,
@@ -158,7 +165,7 @@ class TestSurveyEndpoints:
                 },
                 "updated_by": "B23ABCC4-3A53-FB32-7B78-3960CC907F25",
                 "updated_on": {
-                    "date": "2021-10-20 16:25:16.000000",
+                    "date": "2021-10-20 14:25:16.000000",
                     "timezone_type": 3,
                     "timezone": "Europe/Amsterdam",
                 },
@@ -172,6 +179,7 @@ class TestSurveyEndpoints:
                         "institute_id": "1CFF5802-0B07-471F-B97E-B5166332F2C5",
                         "name": "Test Institute",
                         "abbreviation": "TES",
+                        "date_format": "d-m-Y",
                         "code": "TES",
                         "order": 0,
                         "deleted": False,
@@ -194,6 +202,7 @@ class TestSurveyEndpoints:
                 "institute_id": "1CFF5802-0B07-471F-B97E-B5166332F2C5",
                 "name": "Test Institute",
                 "abbreviation": "TES",
+                "date_format": "d-m-Y",
                 "code": "TES",
                 "order": 0,
                 "deleted": False,
@@ -221,7 +230,12 @@ class TestSurveyEndpoints:
                 "default_invitation_subject": "Please fill in this survey for Example Study",
                 "sender_email": "no-reply@castoredc.com",
                 "is_mobile": False,
+                "is_training": False,
+                "is_repeatable": False,
+                "is_resumable": False,
+                "as_needed": False,
                 "expire_after_hours": None,
+                "field_pagination": "none",
                 "allow_open_survey_link": False,
                 "_embedded": {
                     "surveys": [
@@ -322,7 +336,7 @@ class TestSurveyEndpoints:
         """Test calling on a non-existent survey"""
         with pytest.raises(HTTPStatusError) as e:
             client.single_survey("D70C1273-B5D8-45CD-BFE8-A0BA75C4FAKE")
-        assert "404 Client Error: Not Found for url" in str(e.value)
+        assert e.value.response.status_code == 404
 
     # SURVEY PACKAGES
     def test_all_survey_packages(self, all_survey_packages):
@@ -343,7 +357,7 @@ class TestSurveyEndpoints:
         """Test calling on a non-existent survey package"""
         with pytest.raises(HTTPStatusError) as e:
             client.single_survey_package("71C01598-4682-4A4C-90E6-69C0BD38FAKE")
-        assert "404 Client Error: Not Found for url" in str(e.value)
+        assert e.value.response.status_code == 404
 
     # SURVEY PACKAGE INSTANCES
     def test_all_survey_package_instances(self, all_survey_package_instances):
@@ -397,7 +411,7 @@ class TestSurveyEndpoints:
             client.all_survey_package_instances(
                 record_id="000001", finished_on="14-08-2020"
             )
-        assert "422 Client Error: Unprocessable Entity for url" in str(e.value)
+        assert e.value.response.status_code == 422
 
     def test_all_survey_package_instance_record_fail(
         self, client, all_survey_package_instances
@@ -405,7 +419,7 @@ class TestSurveyEndpoints:
         """Test filtering on non-existent record"""
         with pytest.raises(HTTPStatusError) as e:
             client.all_survey_package_instances(record_id="00FAKE")
-        assert "404 Client Error: Not Found for url" in str(e.value)
+        assert e.value.response.status_code == 404
 
     def test_single_survey_package_instance_success(
         self, client, all_survey_package_instances
@@ -424,66 +438,66 @@ class TestSurveyEndpoints:
             client.single_survey_package_instance(
                 "115DF660-A00A-4927-9E5F-A07D030DFAKE"
             )
-        assert "404 Client Error: Not Found for url" in str(e.value)
+        assert e.value.response.status_code == 404
 
     # POST
-    def test_create_survey_package_instance_success(self, client):
+    def test_create_survey_package_instance_success(self, write_client):
         """Tests creating a new survey package instance"""
-        old_amount = len(client.all_survey_package_instances(record_id="000001"))
-        body = create_survey_package_instance_body("000001", fake=False)
+        old_amount = len(write_client.all_survey_package_instances(record_id="110001"))
+        body = create_survey_package_instance_body("110001", fake=False)
 
-        feedback = client.create_survey_package_instance(**body)
+        feedback = write_client.create_survey_package_instance(**body)
 
-        new_amount = len(client.all_survey_package_instances(record_id="000001"))
+        new_amount = len(write_client.all_survey_package_instances(record_id="110001"))
 
-        assert feedback["record_id"] == "000001"
+        assert feedback["record_id"] == "110001"
         assert new_amount == old_amount + 1
 
-    def test_create_survey_package_instance_fail(self, client):
+    def test_create_survey_package_instance_fail(self, write_client):
         """Tests failing to create a new survey package instance by wrong survey_instance_id"""
-        body = create_survey_package_instance_body("000001", fake=True)
-        old_amount = len(client.all_survey_package_instances(record_id="000001"))
+        body = create_survey_package_instance_body("110001", fake=True)
+        old_amount = len(write_client.all_survey_package_instances(record_id="110001"))
 
         with pytest.raises(HTTPStatusError) as e:
-            client.create_survey_package_instance(**body)
-        assert "422 Client Error: Unprocessable Entity for url:" in str(e.value)
+            write_client.create_survey_package_instance(**body)
+        assert e.value.response.status_code == 422
 
-        new_amount = len(client.all_survey_package_instances(record_id="000001"))
+        new_amount = len(write_client.all_survey_package_instances(record_id="110001"))
         assert new_amount == old_amount
 
-    def test_lock_unlock_survey_package_instance_success(self, client):
+    def test_lock_unlock_survey_package_instance_success(self, write_client):
         """Tests patching (locking/unlocking) a survey_package_instance"""
-        package = client.single_survey_package_instance(
-            "23B4FD48-BA41-4C9B-BAEF-D5C3DD5F8E5C"
+        package = write_client.single_survey_package_instance(
+            "CEF2F230-9F52-45C7-A92D-27B93A5E2B23"
         )
         old_status = package["locked"]
 
         target_status = not old_status
-        client.lock_unlock_survey_package_instance(
-            "23B4FD48-BA41-4C9B-BAEF-D5C3DD5F8E5C", target_status
+        write_client.lock_unlock_survey_package_instance(
+            "CEF2F230-9F52-45C7-A92D-27B93A5E2B23", target_status
         )
 
-        package = client.single_survey_package_instance(
-            "23B4FD48-BA41-4C9B-BAEF-D5C3DD5F8E5C"
+        package = write_client.single_survey_package_instance(
+            "CEF2F230-9F52-45C7-A92D-27B93A5E2B23"
         )
         new_status = package["locked"]
         assert new_status is not old_status
 
-    def test_lock_unlock_survey_package_instance_failure(self, client):
+    def test_lock_unlock_survey_package_instance_failure(self, write_client):
         """Tests failing to lock/unlock a survey_package_instance"""
-        package = client.single_survey_package_instance(
-            "23B4FD48-BA41-4C9B-BAEF-D5C3DD5F8E5C"
+        package = write_client.single_survey_package_instance(
+            "CEF2F230-9F52-45C7-A92D-27B93A5E2B23"
         )
         old_status = package["locked"]
         target_status = not old_status
         fake_id = "23B4FD48-BA41-4C9B-BAEF-D5C3DD5FFAKE"
 
         with pytest.raises(HTTPStatusError) as e:
-            client.lock_unlock_survey_package_instance(fake_id, target_status)
-        assert "404 Client Error: Not Found for url" in str(e.value)
+            write_client.lock_unlock_survey_package_instance(fake_id, target_status)
+        assert e.value.response.status_code == 404
 
-        package = client.single_survey_package_instance(
-            "23B4FD48-BA41-4C9B-BAEF-D5C3DD5F8E5C"
+        package = write_client.single_survey_package_instance(
+            "CEF2F230-9F52-45C7-A92D-27B93A5E2B23"
         )
         new_status = package["locked"]
         assert new_status is old_status
@@ -525,7 +539,7 @@ class TestSurveyEndpoints:
 
         with pytest.raises(HTTPStatusError) as e:
             client.update_start_time_survey_package_instance("000001", fake_id, now)
-        assert "404 Client Error: Not Found for url" in str(e.value)
+        assert e.value.response.status_code == 404
 
         package = client.single_survey_package_instance(
             "3936CDF8-7F8E-45B4-9957-1BCEEAC78DD4"
