@@ -6,7 +6,7 @@ from castoredc_api.importer.helpers import read_excel, castorize_column
 class TestFormatTranslation:
     """Tests the helper functions for translation of external variable values to Castor values."""
 
-    @pytest.fixture(scope="class")
+    @pytest.fixture(scope="function")
     def study_value_data_format(self):
         dataframe = read_excel(
             "tests/test_import/data_files_for_import_tests/data_file_study_values_format.xlsx"
@@ -27,6 +27,8 @@ class TestFormatTranslation:
                 "datetime": "%B %d %Y %I:%M %p",
                 "time": "%I:%M %p",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {
             "record_id": ["110001", "110002", "110003", "110004", "110005"]
@@ -46,6 +48,8 @@ class TestFormatTranslation:
                 "datetime": "%B %d %Y %I:%M %p",
                 "time": "%I:%M %p",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {"his_family": ["2;3;4", "1;2", "0", "5;7", "8"]}
 
@@ -63,6 +67,8 @@ class TestFormatTranslation:
                 "datetime": "%B %d %Y %I:%M %p",
                 "time": "%I:%M %p",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {
             "base_bl_date": [
@@ -88,6 +94,8 @@ class TestFormatTranslation:
                 "datetime": "%B %d %Y %I:%M %p",
                 "time": "%I:%M %p",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {
             "onset_stroke": [
@@ -113,6 +121,8 @@ class TestFormatTranslation:
                 "datetime": "%B %d %Y %I:%M %p",
                 "time": "%I:%M %p",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {"pat_race": ["1", "2", "3", "4", "5"]}
 
@@ -130,6 +140,8 @@ class TestFormatTranslation:
                 "datetime": "%B %d %Y %I:%M %p",
                 "time": "%I:%M %p",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {
             "fac_V_leiden": [
@@ -155,6 +167,8 @@ class TestFormatTranslation:
                 "datetime": "%B %d %Y %I:%M %p",
                 "time": "%I:%M %p",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {"base_hb": ["8.3", "7.2", "9.1", "3.2", "10.3"]}
 
@@ -172,6 +186,8 @@ class TestFormatTranslation:
                 "datetime": "%B %d %Y %I:%M %p",
                 "time": "%I:%M %p",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {"pat_sex": ["0", "0", "1", "1", "0"]}
 
@@ -189,6 +205,8 @@ class TestFormatTranslation:
                 "datetime": "%B %d %Y %I:%M %p",
                 "time": "%I:%M %p",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {
             "onset_trombectomy": ["09:25", "06:33", "12:24", "23:23", "08:14"]
@@ -208,6 +226,8 @@ class TestFormatTranslation:
                 "datetime": "%B %d %Y %I:%M %p",
                 "time": "%I:%M %p",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {
             "pat_birth_year": ["1999", "1956", "1945", "1933", "1921"]
@@ -217,7 +237,7 @@ class TestFormatTranslation:
 class TestFormatTranslationMissing:
     """Tests the helper functions for translation of external variable values to Castor values with missing values."""
 
-    @pytest.fixture(scope="class")
+    @pytest.fixture(scope="function")
     def study_value_data_format_missing(self):
         dataframe = read_excel(
             "tests/test_import/data_files_for_import_tests/data_file_study_values_missings_format.xlsx"
@@ -238,6 +258,8 @@ class TestFormatTranslationMissing:
                 "datetime": "%B %d %Y %I:%M %p",
                 "time": "%I:%M %p",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {
             "record_id": ["110001", "110002", "110003", "110004", "110005"]
@@ -259,6 +281,8 @@ class TestFormatTranslationMissing:
                 "datetime": "%B %d %Y %I:%M %p",
                 "time": "%I:%M %p",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {"his_family": [None, None, "0", "5;7", "8"]}
 
@@ -276,6 +300,8 @@ class TestFormatTranslationMissing:
                 "datetime": "%B %d %Y %I:%M %p",
                 "time": "%I:%M %p",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {
             "base_bl_date": [
@@ -303,6 +329,8 @@ class TestFormatTranslationMissing:
                 "datetime": "%B %d %Y %I:%M %p",
                 "time": "%I:%M %p",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {
             "onset_stroke": [
@@ -330,6 +358,8 @@ class TestFormatTranslationMissing:
                 "datetime": "%B %d %Y %I:%M %p",
                 "time": "%I:%M %p",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {"pat_race": ["1", "2", None, "4", "5"]}
 
@@ -349,6 +379,8 @@ class TestFormatTranslationMissing:
                 "datetime": "%B %d %Y %I:%M %p",
                 "time": "%I:%M %p",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {
             "fac_V_leiden": [
@@ -374,6 +406,8 @@ class TestFormatTranslationMissing:
                 "datetime": "%B %d %Y %I:%M %p",
                 "time": "%I:%M %p",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {"base_hb": ["8.3", None, "9.1", "3.2", "10.3"]}
 
@@ -391,6 +425,8 @@ class TestFormatTranslationMissing:
                 "datetime": "%B %d %Y %I:%M %p",
                 "time": "%I:%M %p",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {"pat_sex": ["0", "0", None, "1", "0"]}
 
@@ -408,6 +444,8 @@ class TestFormatTranslationMissing:
                 "datetime": "%B %d %Y %I:%M %p",
                 "time": "%I:%M %p",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {
             "onset_trombectomy": ["09:25", "06:33", "12:24", None, "08:14"]
@@ -427,6 +465,8 @@ class TestFormatTranslationMissing:
                 "datetime": "%B %d %Y %I:%M %p",
                 "time": "%I:%M %p",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {"pat_birth_year": ["1999", None, None, None, "1921"]}
 
@@ -434,7 +474,7 @@ class TestFormatTranslationMissing:
 class TestFormatTranslationFail:
     """Tests the helper functions for translation of erronous external variable values to Castor values."""
 
-    @pytest.fixture(scope="class")
+    @pytest.fixture(scope="function")
     def study_value_data_format_error(self):
         dataframe = read_excel(
             "tests/test_import/data_files_for_import_tests/data_file_study_values_errors_format.xlsx"
@@ -455,6 +495,8 @@ class TestFormatTranslationFail:
                 "datetime": "%B %d %Y %I:%M %p",
                 "time": "%I:%M %p",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {
             "base_bl_date": [
@@ -480,6 +522,8 @@ class TestFormatTranslationFail:
                 "datetime": "%B %d %Y %I:%M %p",
                 "time": "%I:%M %p",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {
             "onset_stroke": [
@@ -505,6 +549,8 @@ class TestFormatTranslationFail:
                 "datetime": "%B %d %Y %I:%M %p",
                 "time": "%I:%M %p",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {
             "fac_V_leiden": [
@@ -530,6 +576,8 @@ class TestFormatTranslationFail:
                 "datetime": "%B %d %Y %I:%M %p",
                 "time": "%I:%M %p",
             },
+            target=None,
+            target_name=None,
         )
         assert import_column == {
             "onset_trombectomy": [
